@@ -1,4 +1,4 @@
-/* $Id: bomb.h,v 1.1 2004/04/03 14:48:42 stpohle Exp $
+/* $Id: bomb.h,v 1.4 2004/12/01 02:41:54 stpohle Exp $
  * bomb include file
  */
 
@@ -29,9 +29,8 @@ struct {
 		signed char p;			// playernumber of this bomb
 		signed char b;			// bombnumber of this bomb
 	} id;
-    int firer[4];               // range of the fire for the fire for each direction
-    int firerst[4];             /* just save here where the direction was going to stop (-1) 
-								if the exp is still growing */
+    float firer[4];				// range of the fire for the fire for each direction
+	int firemaxr [4];			// max range reached?
     float to;                     // timeout in ms after dropping the bomb. (loops * 0.0005sec)
     float frame;                  // frame of the animation
     unsigned char r;            // range of the bomb
@@ -45,13 +44,13 @@ struct {
 
 
 // for the bomb..
-extern int bomb_loop ();
+extern void bomb_loop ();
 extern void bomb_explode (_bomb *bomb, int net);
 extern inline void bomb_action (_bomb *bomb);
 extern void bomb_move (_bomb *bomb);
 extern void get_bomb_on (float x, float y, _point bombs[]);
-extern void do_explosion (_bomb *bomb);
-extern void restore_explosion (_bomb * bomb);
+extern void explosion_do (_bomb *bomb);
+extern void explosion_restore (_bomb * bomb);
 extern int explosion_check_field (int x, int y, _bomb *bomb);
 
 
