@@ -1,4 +1,4 @@
-/* $Id: packets.h,v 1.31 2004/12/26 04:19:21 stpohle Exp $
+/* $Id: packets.h,v 1.32 2005/03/27 01:31:50 stpohle Exp $
  * network packets.. */
 
 #ifndef _PACKETS_H_
@@ -14,6 +14,7 @@
  * are between all clients so they will be forwarded.					*/
 enum _network_data {
     PKG_error = 0,
+	PKG_gameinfo,
 	PKG_joingame,	// every packet below here will checked 
 					// if it comes from a orginal player
 	PKG_contest,	
@@ -332,6 +333,19 @@ struct pkg_mapinfo {
 };
 
 
+/* this packet type is also used in netsrvlist.c */
+struct pkg_gameinfo {
+	struct pkgheader h;
+	Uint32 timestamp;
+	unsigned char curplayers;
+	unsigned char maxplayers;
+	char gamename[LEN_GAMENAME];
+	char version[LEN_VERSION];
+	char broadcast;
+	signed char password;		/* if password == -1, we do a game request */
+};
+
+
 struct _rscache_entry {
 	signed char pl_nr;			// playernumber to whom this data should go
 	Sint16 len;				    // size of the entry
@@ -383,7 +397,8 @@ extern void do_dropitems (struct pkg_dropitem *di_pkg, _net_addr *addr);
 extern void do_respawn (struct pkg_respawn *r_pkg, _net_addr *addr);
 extern void do_contest (struct pkg_contest *ct_pkg, _net_addr *addr);
 extern void do_teamdata (struct pkg_teamdata *td, _net_addr * addr);
-	
+extern void do_gameinfo (struct pkg_gameinfo *pgi, _net_addr *addr);
+
 extern void send_pkg (struct pkg *packet, _net_addr *addr);
 extern void send_playerid (_net_addr *addr, char *name, char *pladdr, char *plport, int p_nr, int gfx_nr, int team_nr, signed char netflags);
 extern void send_servermode (_net_addr *addr, int pl_nr);
@@ -410,6 +425,7 @@ extern void send_dropitems (_net_addr *addr, int pl_nr, _flyingitem **fitems, in
 extern void send_respawn (_net_addr * addr, int plnr);
 extern void send_contest (_net_addr * addr, int from, int to, int ackreq);
 extern void send_teamdata (_net_addr * addr, int team_nr);
+extern void send_gameinfo (_net_addr * addr, int sock, int broadcast);
 
 extern void fwd_pkg (struct pkg *packet, _net_addr *addr);
 
