@@ -1,4 +1,4 @@
-/* $Id: bomb.c,v 1.61 2004/12/01 02:41:54 stpohle Exp $ */
+/* $Id: bomb.c,v 1.62 2005/02/20 19:11:20 stpohle Exp $ */
 /* everything what have to do with the bombs */
 
 #include "bomberclone.h"
@@ -523,7 +523,7 @@ int explosion_check_field (int x, int y, _bomb *bomb)
             && (GT_SP
 				|| (GT_MP && (&players[bman.p_nr] == tmpplayer || (IS_LPLAYER2 && &players[bman.p2_nr] == tmpplayer)))
                 || (GT_MP_PTPM && PS_IS_aiplayer (tmpplayer->state))))
-            player_died (tmpplayer, bomb->id.p);
+            player_died (tmpplayer, bomb->id.p, 0);
     }
 
     // let the stones right beside explode
