@@ -1,4 +1,4 @@
-/* $Id: configuration.c,v 1.69 2004/12/26 04:19:20 stpohle Exp $
+/* $Id: configuration.c,v 1.72 2005/03/28 16:38:34 stpohle Exp $
  * configuration */
 
 #include <SDL.h>
@@ -524,7 +524,8 @@ config_video ()
         {"640x480", NULL},
         {"800x600", NULL},
         {"1024x768", NULL},
-        {"1280x1024", NULL}
+        {"1280x1024", NULL},
+        {"1600x1200", NULL}
     };
     _charlist screenbpp[] = {
         {"16", NULL},
@@ -538,7 +539,7 @@ config_video ()
 	_menu *menu;
 	
     /* set all pointers in this array */
-    charlist_fillarraypointer (screenres, 4);
+    charlist_fillarraypointer (screenres, 5);
     charlist_fillarraypointer (screenbpp, 3);
 
     /* select the current settings */
@@ -550,11 +551,11 @@ config_video ()
     while (!done && bman.state != GS_quit) {
         menu = menu_new ("Video Setup", 325, 300);
         menu_create_label (menu, "Resolution", 25, 70, 0, COLOR_brown);
-        menu_create_list (menu, "res", 155, 55, 150, 70, screenres, &selres, 1);
-        menu_create_label (menu, "Colors", 65, 160, 0, COLOR_brown);
-        menu_create_list (menu, "bpp", 195, 145, 50, 55, screenbpp, &selbpp, 2);
-        menu_create_bool (menu, "Fullscreen", -1, 210, 150, &gfx.fullscreen, 3);
-        menu_create_button (menu, "OK", -1, 250, 100, 0);
+        menu_create_list (menu, "res", 155, 55, 150, 85, screenres, &selres, 1);
+        menu_create_label (menu, "Colors", 65, 170, 0, COLOR_brown);
+        menu_create_list (menu, "bpp", 195, 155, 50, 55, screenbpp, &selbpp, 2);
+        menu_create_bool (menu, "Fullscreen", -1, 220, 150, &gfx.fullscreen, 3);
+        menu_create_button (menu, "OK", -1, 260, 100, 0);
         menuselect = menu_loop (menu);
         menu_delete (menu);
 
@@ -660,6 +661,7 @@ ReadPrgArgs (int argc, char **argv)
             printf ("\nProgramm options:\n");
             printf (" -name PLAYERNAME   - set the Playername\n");
             printf (" -name2 PLAYERNAME  - set the Playername for the second player\n");
+			printf (" -gamename GAMENAME - set the name of the game\n");
             printf (" -port PORT         - set the local BomberClone port\n");
 			printf ("                      (Def.: 11000)\n");
             printf (" -ogcport PORT      - set the local OGC Port (Def.: 11100)\n");
@@ -678,6 +680,8 @@ ReadPrgArgs (int argc, char **argv)
             strncpy (bman.playername, argv[++i], LEN_PLAYERNAME);
         if (!strcmp (argv[i], "-name2"))
             strncpy (bman.player2name, argv[++i], LEN_PLAYERNAME);
+		if (!strcmp (argv[i], "-gamename"))
+			strncpy (bman.gamename, argv[++i], LEN_GAMENAME);
         if (!strcmp (argv[i], "-ogc"))
             bman.notifygamemaster = atoi (argv[++i]);
         if (!strcmp (argv[i], "-debug"))
@@ -707,3 +711,27 @@ ReadPrgArgs_Jump (int argc, char **argv)
 		}
 	}
 };
+
+
+/* check the version number, return [ 0 =] [-1 <] [ 1 >] */
+int check_version (int ma, int mi, int su, char *ver) {
+	int v1, v2, v3, res = 0;
+
+	sscanf (ver, "%d.%d.%d", &v1, &v2, &v3);
+	if (v1 < ma)
+		res = -1;
+	else if (v1 > ma)
+		res = 1;
+	else if (v2 < mi)
+		res = -1;
+	else if (v2 > mi)
+		res = 1;
+	else if (v3 < su)
+		res = -1;
+	else if (v3 > su)
+		res = 1;
+
+	// d_printf ("version_check (%d.%d.%d, %s = %d\n" , ma, mi, su, ver, res);
+	
+	return res;
+};
