@@ -1,4 +1,4 @@
-/* $Id: game.c,v 1.106 2004/12/26 04:19:20 stpohle Exp $ 
+/* $Id: game.c,v 1.107 2005/02/14 20:09:19 stpohle Exp $ 
   game.c - procedures for the game. */
 
 #include <string.h>
@@ -501,8 +501,8 @@ game_start ()
         bman.updatestatusbar=1;
         players[p].frame = 0.0f;
         players[p].d = 0;
-        players[p].pos.x = -1;
-        players[p].pos.y = -1;
+        players[p].pos.x = 0.0;
+        players[p].pos.y = 0.0;
 		players[p].tunnelto = 0.0f;
 		players[p].ready = 0;
 
@@ -520,6 +520,8 @@ game_start ()
 			players[p].bombs[i].mode = BM_normal;
 			players[p].bombs[i].id.p = p;
 			players[p].bombs[i].id.b = i;
+			players[p].pos.x = 0;
+			players[p].pos.x = 0;
         }
     }
 	
