@@ -1,4 +1,4 @@
-/* $Id: menu.c,v 1.49 2004/09/13 22:04:24 stpohle Exp $
+/* $Id: menu.c,v 1.50 2005/03/27 01:31:50 stpohle Exp $
  * Menuhandling */
 
 #include "basic.h"
@@ -206,8 +206,9 @@ menu_draw (_menu * menu)
 
     menu_draw_border (menu);
 
-    for (m = menu->items; m != NULL; m = m->next)
+    for (m = menu->items; m != NULL; m = m->next) {
         menu_draw_menuitem (m);
+	}
 };
 
 
