@@ -142,10 +142,7 @@ multiplayer_firstrun ()
  * We will host a network game
  */
 void host_multiplayer_game () {
-	if (bman.firewall) {
-		menu_displaymessage("Error", "You can not start a network game\nwith the firewall option on.");
-		return;
-	}
+	bman.firewall = 0;
 	multiplayer_firstrun ();
 
     if (network_init () < 0) {
@@ -192,7 +189,7 @@ void multiplayer_game () {
 					net_send_servermode ();
 
                 game_loop ();
-                if (bman.state == GS_running)
+                if (bman.state == GS_running || bman.state == GS_ready)
                     bman.state = GS_wait;
 
                 bman.lastwinner = -1;
