@@ -179,14 +179,6 @@ do_joingame (struct pkg_joingame *p_jg, _net_addr * addr)
             send_servermode (addr, i); // with this packet the client know it'S pl_nr
 
             addr->pl_nr = i;
-
-            /* Send all connected players the new PlayerID, except to the new player 
-			for (i = 0; i < MAX_PLAYERS; i++)
-				if (NET_CANSEND(i) && addr->pl_nr != i)
-                    send_playerid (&players[i].net.addr, pl->name, pl->net.addr.host,
-                                   pl->net.addr.port, pl->net.addr.pl_nr, pl->gfx_nr,
-                                   pl->team_nr, pl->net.flags);
-			*/
         }
 
         else if (GS_WAITRUNNING) {
@@ -323,7 +315,8 @@ do_playerid (struct pkg_playerid *p_id, _net_addr * addr)
 	/*
 	 * check if we have to update someones data
 	 */
-	else if ((GT_MP_PTPM && p_id->pl_nr >= 0 && p_id->pl_nr < MAX_PLAYERS && p_id->pl_nr != bman.p_nr && p_id->pl_nr != bman.p2_nr)
+	else if ((GT_MP_PTPM && p_id->pl_nr >= 0 && p_id->pl_nr < MAX_PLAYERS && 
+			  p_id->pl_nr != bman.p_nr && p_id->pl_nr != bman.p2_nr && bman.state == GS_wait)
 			 || (GT_MP_PTPS && p_id->pl_nr >= 0 && p_id->pl_nr < MAX_PLAYERS)) {
 
         pl = &players[p_id->pl_nr];
@@ -348,7 +341,9 @@ do_playerid (struct pkg_playerid *p_id, _net_addr * addr)
 		
 		/* Check if we have to make a network test.. only client to client 
 		 * we won't check 2 players too because i't won't be possible to send
-		 * something to them. Start the timer for the connection test. */
+		 * something to them. 
+		 *
+		 * Check only as long as pl->state is still not a network player */
 		if (GT_MP_PTPS && !(PS_IS_netplayer (pl->state)) && (PS_IS_netplayer (p_id->state))
 			&& p_id->pl_nr != bman.p_servnr && p_id->pl_nr != bman.p_nr
 			&& !(pl->net.flags & NETF_local2) && p_id->pl_nr != bman.p2_nr) {
@@ -382,7 +377,16 @@ do_playerid (struct pkg_playerid *p_id, _net_addr * addr)
             net_send_playerid (addr->pl_nr);
 	}
 	
-  //  d_playerdetail ("*** PLAYER List ***");
+	/*
+	 * if we are already in a game don't let the player change the gfx */
+	else if (GT_MP_PTPM && p_id->pl_nr >= 0 && p_id->pl_nr < MAX_PLAYERS && 
+			 p_id->pl_nr != bman.p_nr && p_id->pl_nr != bman.p2_nr && bman.state != GS_wait) {
+        /* Send all connected players the new PlayerID */
+        if (GT_MP_PTPM && GS_WAITRUNNING && addr->pl_nr >= 0 && addr->pl_nr < MAX_PLAYERS)
+            net_send_playerid (addr->pl_nr);
+	}
+	
+	//  d_playerdetail ("*** PLAYER List ***");
 	team_update ();
     bman.updatestatusbar = 1;
 };
@@ -828,6 +832,7 @@ do_playerdata (struct pkg_playerdata *p_dat, _net_addr * addr)
 				if (bman.gametype == GT_team && players[p_dat->dead_by].team_nr >= 0 && players[p_dat->dead_by].team_nr < MAX_TEAMS)
 					teams[players[p_dat->dead_by].team_nr].points++;
                 net_game_send_player (p_dat->dead_by);
+				player_died (pl, p_dat->dead_by, 1);
             }
         }
         pl->state = p_dat->state;
@@ -1629,6 +1634,49 @@ void do_respawn (struct pkg_respawn *r_pkg, _net_addr *addr) {
 
 
 
+/***
+ *** gameinfo packet is used to get some data from a running game
+ *** just fill in the informations we need and send this packet back.
+ ***/
+void do_gameinfo (struct pkg_gameinfo *pgi, _net_addr *addr) {
+	if (GT_MP_PTPM && pgi->password == -1) {
+		d_printf ("do_gameinfo (from: %s:%s) Broadcast Req: %d\n", addr->host, addr->port, pgi->broadcast);
+		
+		strncpy (pgi->version, VERSION, LEN_VERSION);
+		pgi->maxplayers = bman.maxplayer;
+		pgi->curplayers = bman.players_nr_s;
+		strncpy (pgi->gamename, bman.gamename, LEN_GAMENAME);
+		send_pkg ((struct pkg*) pgi, addr);
+	}
+	else if (pgi->password != -1)
+		d_printf ("do_gameinfo (from: %s:%s) ** NO REQUEST **\n", addr->host, addr->port);
+	else 
+		d_printf ("do_gameinfo (from: %s:%s) ** WE ARE NOT THE MASTER OF THIS GAME **\n", addr->host, addr->port);
+	
+}
+
+
+void send_gameinfo (_net_addr * addr, int sock, int broadcast) {
+    struct pkg_gameinfo pgi;
+
+    pgi.h.typ = PKG_gameinfo;
+    pgi.h.len = HTON16 (sizeof (struct pkg_gameinfo));
+    pgi.h.flags = 0;
+    pgi.timestamp = timestamp;
+	pgi.gamename[0] = 0;
+	pgi.version[0] = 0;
+	pgi.password = -1;
+	pgi.broadcast = broadcast;
+		
+    if (bman.net_ai_family != PF_INET)
+        pgi.h.flags = pgi.h.flags | PKGF_ipv6;
+	if (broadcast)
+		udp_sendbroadcast (sock, (char *) &pgi, NTOH16 (pgi.h.len), &addr->sAddr, bman.net_ai_family);
+	else
+		udp_send (sock, (char *) &pgi, NTOH16 (pgi.h.len), &addr->sAddr, bman.net_ai_family);
+};
+
+
 /***
  *** general packet handling, like check for double recived packets
  *** network type. Autoreply on PKGF_ackreq and such things.
@@ -1783,6 +1831,9 @@ do_pkg (struct pkg *packet, _net_addr * addr)
         if (do_error ((struct pkg_error *) packet, addr) < 0)
             return -1;
         break;
+	case (PKG_gameinfo):
+		do_gameinfo ((struct pkg_gameinfo *) packet, addr);
+		break;
     case (PKG_playerid):
         do_playerid ((struct pkg_playerid *) packet, addr);
         break;
