@@ -1,4 +1,4 @@
-/* $Id: single.c,v 1.82 2004/12/26 04:19:20 stpohle Exp $ */
+/* $Id: single.c,v 1.84 2005/02/14 20:09:19 stpohle Exp $ */
 /* single player */
 
 #include "basic.h"
@@ -7,7 +7,6 @@
 #include "player.h"
 #include "single.h"
 
-
 /* start a single player game and prepare everything for the game */
 void
 single_game_new ()
@@ -258,6 +257,12 @@ ai_bombpoints (_point pos, int range)
         r;
     _point p;
 
+	if (pos.x < 0 || pos.x >= MAX_FIELDSIZE_X || pos.y < 0 || pos.y >= MAX_FIELDSIZE_Y) {
+		printf ("WARNING: ai_bombpoints: pos out of range.\n");
+		printf ("         pos.x=%d pos.y=%d range=%d\n", pos.x, pos.y, range);
+		return 0;
+	}
+		
     if (map.field[pos.x][pos.y].type != FT_block && map.field[pos.x][pos.y].type != FT_stone
         && ai_checkfield (pos.x, pos.y)) {
         for (d = 0; d < 4; d++) {
@@ -265,18 +270,20 @@ ai_bombpoints (_point pos, int range)
 
             for (r = 0;
                  (r < range
-                  && (map.field[p.x][p.y].type == FT_nothing
-                      || map.field[p.x][p.y].type == FT_tunnel)); r++) {
+                  && (p.x >= 0 && p.x < map.size.x && p.y >= 0 && p.y < map.size.y) 
+				  && (map.field[p.x][p.y].type == FT_nothing || map.field[p.x][p.y].type == FT_tunnel)); r++) {
                 p.x += dir_change[d].x;
                 p.y += dir_change[d].y;
             }
 
-            if (map.field[p.x][p.y].type != FT_nothing && map.field[p.x][p.y].type != FT_tunnel
+            if ((p.x >= 0 && p.x < map.size.x && p.y >= 0 && p.y < map.size.y)
+				&& map.field[p.x][p.y].type != FT_nothing && map.field[p.x][p.y].type != FT_tunnel
                 && (map.field[p.x][p.y].type != FT_block || map.field[p.x][p.y].type == FT_shoe
                     || map.field[p.x][p.y].type == FT_bomb || map.field[p.x][p.y].type == FT_fire))
                 points++;
-            if (map.field[p.x][p.y].type == FT_shoe || map.field[p.x][p.y].type == FT_bomb ||
-                map.field[p.x][p.y].type == FT_fire)
+            if ((p.x >= 0 && p.x < map.size.x && p.y >= 0 && p.y < map.size.y)
+				&& (map.field[p.x][p.y].type == FT_shoe || map.field[p.x][p.y].type == FT_bomb ||
+                   map.field[p.x][p.y].type == FT_fire))
                 points += 2;
         }
     }
