@@ -1,4 +1,4 @@
-/* $Id: udp.c,v 1.12 2004/11/29 09:45:53 stpohle Exp $ */
+/* $Id: udp.c,v 1.13 2005/03/27 01:31:50 stpohle Exp $ */
 /* udp.c code for the network
 	File Version 0.2
 */
@@ -156,6 +156,18 @@ udp_send (int sock, char *text, int len, struct _sockaddr *sAddr, int ai_family)
 };
 
 
+/* send udp broadcasted message */
+void udp_sendbroadcast (int sock, char *text, int len, struct _sockaddr *sAddr, int ai_family)
+{
+	int value;
+	
+	value = 1;
+	setsockopt(sock, SOL_SOCKET, SO_BROADCAST, &value, sizeof (value));
+	udp_send (sock, text, len, sAddr, ai_family);
+	value = 0;
+	setsockopt(sock, SOL_SOCKET, SO_BROADCAST, &value, sizeof (value));
+};
+
 int
 udp_server (char *port, int ai_family)
 {
